@@ -17,6 +17,13 @@
 from .base import (  # noqa
     Base,
 )
+from .user import (  # noqa
+    NulabAccount,
+    User,
+)
+from .project import (  # noqa
+    Project,
+)
 from .space import (  # noqa
     Space,
 )
